//
//  ContentView.swift
//  ButtonRepeatBehavior
//
//  Created by Gabriel Theodoropoulos.
//

import SwiftUI

struct ContentView: View {
    @State private var volume = 50
    
    var body: some View {
        // Increase or decrease the volume value using a Stepper control.
        /*
         Stepper("Volume \(volume)", value: $volume, in: 0...100)
         .padding(.horizontal)
         */
        
        
        // An alternative implementation that uses custom buttons
        // and the buttonRepeatBehavior view modifier.
        VStack {
            Text("Volume \(volume)")
                .font(.largeTitle)
            
            HStack(spacing: 30) {
                // The first button to decrease the volume.
                Button(action: {
                    volume -= 1
                }) {
                    Image(systemName: "minus")
                        .font(.title)
                        .frame(width: 44, height: 44)
                }
                .buttonStyle(.bordered)
                .clipShape(Circle())
                // Enable repeating the action with the buttonRepeatBehavior modifier!
                .buttonRepeatBehavior(.enabled)
                
                
                // The second button to increase the volume.
                Button(action: {
                    volume += 1
                }) {
                    Image(systemName: "plus")
                        .font(.title)
                        .frame(width: 44, height: 44)
                    
                }
                .buttonStyle(.bordered)
                .clipShape(Circle())
                // Enable repeating the action with the buttonRepeatBehavior modifier!
                .buttonRepeatBehavior(.enabled)
            }
        }
    }
        
    #Preview {
        ContentView()
    }
}
